/*
 * Copyright 2008-2009 SpringSource
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.springsource.bundlor.support.contributors;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Set;

import org.junit.Test;

import com.springsource.bundlor.support.partialmanifest.ReadablePartialManifest;
import com.springsource.bundlor.support.partialmanifest.StandardReadablePartialManifest;

public class WebApplicationArtifactAnalyzerTests {

    private WebApplicationArtifactAnalyzer analyzer = new WebApplicationArtifactAnalyzer();

    @Test
    public void validForAnalyzation() {
        assertTrue("Invalid for standard web.xml file", analyzer.canAnalyse("WEB-INF/web.xml"));
    }

    @Test
    public void invalidForAnalyzation() {
        assertFalse("Invalid for web.xml in META-INF", analyzer.canAnalyse("META-INF/web.xml"));
        assertFalse("Invalid for web.xml in root", analyzer.canAnalyse("web.xml"));
    }

    @Test
    public void contents() throws FileNotFoundException, Exception {
        ReadablePartialManifest partialManifest = new StandardReadablePartialManifest();
        analyzer.analyse(new FileInputStream("src/test/resources/com/springsource/bundlor/support/contributors/web.xml"), "WEB-INF/web.xml",
            partialManifest);

        Set<String> importedPackages = partialManifest.getImportedPackages();
        for (String expectedImportedPackage : new String[] { "alpha", "bravo", "charlie", "delta", "echo", "foxtrot", "golf", "hotel", "indigo",
            "juliet", "lima", "mike", "november", "oscar", "poppa" }) {
            assertTrue("Missing package '" + expectedImportedPackage + "'", importedPackages.contains(expectedImportedPackage));
        }
    }
}
